==> dde-network-core_1.0.47.orig.tar.xz: dde-network-core-1.0.47/dss-network-plugin/translations/dss-network-plugin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 new message</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Connecting %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connected</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 disconnected</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Unable to connect %1, please check your router or net cable.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Unable to connect %1, please keep closer to the wireless router</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Connection failed, unable to connect %1, wrong password</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Password is required to connect %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>The %1 802.11 WLAN network could not be found</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Wired Connection</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Security Type</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Channel</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primary DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Speed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authenticating</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtaining IP address</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connected</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnected</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtaining address</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Wired Network %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Wireless Network %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connection failed</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Disable wired connection</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Enable wired connection</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disable wireless connection</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Enable wireless connection</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disable network</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Enable network</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Network settings</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dss-network-plugin/translations/dss-network-plugin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 new message</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Connecting %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connected</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 disconnected</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Unable to connect %1, please check your router or net cable.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Unable to connect %1, please keep closer to the wireless router</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Connection failed, unable to connect %1, wrong password</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Password is required to connect %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>The %1 802.11 WLAN network could not be found</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connect to hidden network</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Connect</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Name (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Security Type</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Channel</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primary DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Speed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authenticating</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtaining IP address</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connected</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnected</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtaining address</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Wired Network %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Wireless Network %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connection failed</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Disable wired connection</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Enable wired connection</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disable wireless connection</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Enable wireless connection</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disable network</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Enable network</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Network settings</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Wired Connection</translation>
    </message>
</context>
</TS>
